TransformerTextEncoder
======================

.. currentmodule:: pykeen.nn.text

.. autoclass:: TransformerTextEncoder
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~TransformerTextEncoder.forward_normalized

   .. rubric:: Methods Documentation

   .. automethod:: forward_normalized
